@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_iam._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-lambda-at-edge-pattern",
-    "1.0.8",
+    "1.0.10",
     __name__[0:-6],
-    "cdk-lambda-at-edge-pattern@1.0.8.jsii.tgz",
+    "cdk-lambda-at-edge-pattern@1.0.10.jsii.tgz",
 )
 
 __all__ = [
